@@ -440,19 +440,19 @@ FINAL void _writeObjC(NSArchiver *self, const void *_value, const char *_type);
         _writeInt(self, archiveId);
 
         if (tag == _C_CLASS) { // a class object
-            NSString      *className;
-            unsigned      len;
-            unsigned char *buf;
+            NSString *className;
+            unsigned len;
+            char *buf;
             
             className = NSStringFromClass(_object);
             className = [self classNameEncodedForTrueClassName:className];
             len = [className cStringLength];
-            buf = malloc(len + 1);
+            buf = malloc(len + 4);
             [className getCString:buf]; buf[len] = '\0';
             
             _writeCString(self, buf);
             _writeInt(self, [_object version]);
-            free(buf);
+            if (buf) free(buf);
         }
         else {
             Class archiveClass = Nil;
