@@ -61,7 +61,7 @@
 
     if ((bytes = NSReadContentsOfFile(_path, 1, &len))) {
         bytes[len] = '\0';
-        return [self initWithCString:bytes length:len copy:NO];
+        return [self initWithCString:(char *)bytes length:len copy:NO];
     }    
     else {
         self = AUTORELEASE(self);
@@ -98,7 +98,7 @@
     bytes = MallocAtomic (length);
     [aDecoder decodeArrayOfObjCType:@encode(char) count:length at:bytes];
     return [[NSMutableSimple8BitString alloc]
-               initWithCString:bytes length:length copy:NO];
+               initWithCString:(char *)bytes length:length copy:NO];
 }
 
 - (NSData *)dataUsingEncoding:(NSStringEncoding)encoding
@@ -112,7 +112,7 @@
         
         len = [self cStringLength];
         buf = NSZoneMallocAtomic(NULL, len + 1);
-        [self getCString:buf]; buf[len] = '\0';
+        [self getCString:(char *)buf]; buf[len] = '\0';
         
         return [NSData dataWithBytesNoCopy:buf length:len];
     }
@@ -123,7 +123,7 @@
         
         len = [self cStringLength];
         buf = NSZoneMallocAtomic(NULL, len + 1);
-        [self getCString:buf]; buf[len] = '\0';
+        [self getCString:(char *)buf]; buf[len] = '\0';
         
         if (!flag) {
             /* check for strict ANSI */
@@ -140,7 +140,7 @@
 
 /* Accessing characters	*/
 
-- (void)getCharacters:(unichar*)buffer range:(NSRange)aRange
+- (void)getCharacters:(unichar *)buffer range:(NSRange)aRange
 {
     register unsigned int i = 0;
     register unsigned char *bytes;
@@ -152,7 +152,7 @@
             raise];
     }
     
-    bytes = [self __compact8BitBytes];
+    bytes = (unsigned char *)[self __compact8BitBytes];
     for (i = 0; i < aRange.length; i++)
         buffer[i] = bytes[i];
 }
@@ -167,14 +167,14 @@
 
 /* Finding characters and substrings */
 
-- (NSRange)rangeOfCharacterFromSet:(NSCharacterSet*)aSet
+- (NSRange)rangeOfCharacterFromSet:(NSCharacterSet *)aSet
   options:(unsigned int)mask range:(NSRange)aRange
 {
     // ENCODINGS - this code applies to the system's default encoding
     unsigned int i = 0;
-
+    
     IMP imp = [aSet methodForSelector:@selector(characterIsMember:)];
-    unsigned char *bytes = [self __compact8BitBytes];
+    unsigned char *bytes = (unsigned char *)[self __compact8BitBytes];
 
     if (NSMaxRange(aRange) > [self cStringLength]) {
         [[[IndexOutOfRangeException alloc] initWithFormat:
@@ -206,14 +206,16 @@
 
         for (i = aRange.location; i < max; i++) {
             unichar c = bytes[i];
+
+            if ((*imp)(aSet, @selector(characterIsMember:), c))
+                return NSMakeRange(i, 1);
             
-            if ((*imp)(aSet, @selector(characterIsMember:), c) ||
-                ((mask & NSCaseInsensitiveSearch) && 
-                 ((islower(c) &&
-                   (*imp)(aSet, @selector(characterIsMember:), toupper(c))) ||
-                  (isupper(c) &&
-                   (*imp)(aSet, @selector(characterIsMember:), tolower(c))))
-                 ))
+            if ((mask & NSCaseInsensitiveSearch) && 
+                ((islower(c) &&
+                  (*imp)(aSet, @selector(characterIsMember:), toupper(c))) ||
+                 (isupper(c) &&
+                  (*imp)(aSet, @selector(characterIsMember:), tolower(c))))
+                )
             {
                 return NSMakeRange(i, 1);
             }
@@ -244,8 +246,8 @@
             raise];
     }
 
-    mbytes = [self __compact8BitBytes] + aRange.location;
-    abytes = [(id)aString __compact8BitBytes];
+    mbytes = (unsigned char *)[self __compact8BitBytes] + aRange.location;
+    abytes = (unsigned char *)[(id)aString __compact8BitBytes];
     a = [aString cStringLength];
     
     if ((a == 0) || (aRange.length < a))
@@ -388,8 +390,8 @@
             raise];
     }
     
-    mbytes = [self __compact8BitBytes] + aRange.location;
-    abytes = [(id)aString __compact8BitBytes];
+    mbytes = (unsigned char *)[self __compact8BitBytes] + aRange.location;
+    abytes = (unsigned char *)[(id)aString __compact8BitBytes];
     
     a = [aString cStringLength];
     n = MIN(a, aRange.length);
@@ -424,7 +426,7 @@
 
 - (unsigned)hash
 {
-    unsigned char *bytes = [self __compact8BitBytes];
+    unsigned char *bytes = (unsigned char *)[self __compact8BitBytes];
     unsigned hash = 0, hash2;
     int i, n = [self cStringLength];
 
@@ -458,8 +460,8 @@
     
     mLen   = [self cStringLength];
     aLen   = [aString length];
-    mbytes = [self __compact8BitBytes];
-    abytes = [(NS8BitString *)aString __compact8BitBytes];
+    mbytes = (unsigned char *)[self __compact8BitBytes];
+    abytes = (unsigned char *)[(NS8BitString *)aString __compact8BitBytes];
 
     for (i = 0; (i < mLen) && (i < aLen); i++) {
 	unsigned char c1 = mbytes[i];
@@ -485,7 +487,7 @@
     int           i;
     BOOL          f      = YES;
     int           length = [self cStringLength];
-    unsigned char *bytes  = [self __compact8BitBytes];
+    unsigned char *bytes  = (unsigned char *)[self __compact8BitBytes];
     unsigned char *chars  = MallocAtomic(sizeof(unichar)*(length+1));
 
     for (i = 0; i < length; i++) {
@@ -504,7 +506,8 @@
     chars[i] = 0;
     
     return AUTORELEASE([[NSOwned8BitString alloc]
-                           initWithCString:chars length:length copy:NO]);
+                           initWithCString:(char *)chars length:length
+			   copy:NO]);
 }
 
 - (NSString *)lowercaseString
@@ -515,7 +518,7 @@
     unsigned char *chars;
     
     length = [self cStringLength];
-    bytes  = [self __compact8BitBytes];
+    bytes  = (unsigned char *)[self __compact8BitBytes];
     chars  = MallocAtomic(sizeof(unsigned char) * (length + 1));
     
     for (i = 0; i < length; i++) {
@@ -526,7 +529,8 @@
     chars[i] = 0;
 
     return AUTORELEASE([[NSOwned8BitString alloc]
-                           initWithCString:chars length:length copy:NO]);
+                           initWithCString:(char *)chars length:length
+			   copy:NO]);
 }
 
 - (NSString *)uppercaseString
@@ -534,7 +538,7 @@
     // ENCODINGS - this code applies to the system's default encoding
     int i;
     int length = [self cStringLength];
-    unsigned char *bytes = [self __compact8BitBytes];
+    unsigned char *bytes = (unsigned char *)[self __compact8BitBytes];
     unsigned char *chars = MallocAtomic(sizeof(unichar)*(length+1));
 
     for (i = 0; i < length; i++) {
@@ -545,7 +549,8 @@
     chars[i] = 0;
 
     return AUTORELEASE([[NSOwned8BitString alloc]
-                           initWithCString:chars length:length copy:NO]);
+                           initWithCString:(char *)chars length:length
+			   copy:NO]);
 }
 
 /* Working with C strings */
@@ -553,9 +558,9 @@
 - (void)getCString:(char *)buffer maxLength:(unsigned int)maxLength
   range:(NSRange)aRange remainingRange:(NSRange *)leftoverRange
 {
-    unsigned char *bytes = [self __compact8BitBytes];
-    unsigned int toMove = MIN(maxLength, aRange.length);
-    unsigned int cLength = [self cStringLength];
+    unsigned char *bytes  = (unsigned char *)[self __compact8BitBytes];
+    unsigned int  toMove  = MIN(maxLength, aRange.length);
+    unsigned int  cLength = [self cStringLength];
     
     if (NSMaxRange(aRange) > cLength) {
         [[[IndexOutOfRangeException alloc] initWithFormat:
@@ -588,8 +593,8 @@
     const unsigned char *cString;
     int i, length;
 
-    cString = [self __compact8BitBytes];
-    length = [self cStringLength];
+    cString = (unsigned char *)[self __compact8BitBytes];
+    length  = [self cStringLength];
 
     if (cString == NULL)    return @"\"\"";
     if (cString[0] == '\0') return @"\"\"";
@@ -597,12 +602,12 @@
     /* Check if the string can be parsed as a STRING token by the property list
        parser. Otherwise we must enclose it in double quotes. */
     if (lf_isPlistBreakChar(cString[0])) {
-        return lf_quoteString(cString, length);
+        return lf_quoteString((char *)cString, length);
     }
 
     for(i = 1; i < length; i++) {
         if (lf_isPlistBreakChar(cString[i]))
-	    return lf_quoteString(cString, length);
+	    return lf_quoteString((char *)cString, length);
     }
 
     return self;
@@ -670,7 +675,7 @@
     }
     else {
 	lfFree(cString);
-	cString = byteString;
+	cString = (unsigned char *)byteString;
 	cLength = cCapacity = length;
     }
     return self;
@@ -682,7 +687,7 @@
     [super dealloc];
 }
 
-- (const char*)cString
+- (const char *)cString
 {
     unsigned char *str = MallocAtomic(sizeof(char)*(cLength + 1));
 
@@ -691,7 +696,7 @@
 #if !LIB_FOUNDATION_BOEHM_GC
     [NSAutoreleasedPointer autoreleasePointer:str];
 #endif
-    return str;
+    return (const char *)str;
 }
 
 - (unsigned int)cStringLength
@@ -736,13 +741,14 @@
         : [NSInline8BitString class];
     
     return AUTORELEASE([[clazz allocForCapacity:aRange.length zone:NULL] 
-                               initWithCString:(self->cString + aRange.location)
+                               initWithCString:
+			       ((char *)self->cString + aRange.location)
                                length:aRange.length]);
 }
 
-- (char*)__compact8BitBytes
+- (char *)__compact8BitBytes
 {
-    return self->cString;
+    return (char *)self->cString;
 }
 
 - (void)replaceCharactersInRange:(NSRange)aRange
@@ -802,7 +808,7 @@
     if (strLength) {
 	NSRange range = { 0, strLength };
         
-	[aString getCString:(self->cString + aRange.location)
+	[aString getCString:((char *)self->cString + aRange.location)
                  maxLength:strLength
                  range:range
                  remainingRange:NULL];
