@@ -332,18 +332,20 @@
 	}
 	case _C_ARY_B: {
 	    int i, count, offset, itemSize;
-	    const unsigned char* itemType;
-    
+	    const char *itemType;
+	    
 	    count = Atoi(type + 1);
 	    itemType = type;
-	    while(isdigit(*++itemType));
-		itemSize = objc_sizeof_type(itemType);
-
-		for(i = offset = 0; i < count; i++, offset += itemSize)
-		    [self deserializeDataAt:(char*)data + offset
-				    ofObjCType:itemType
-				    atCursor:cursor
-				    context:callback];
+	    while (isdigit(*++itemType))
+		;
+	    itemSize = objc_sizeof_type(itemType);
+		
+	    for(i = offset = 0; i < count; i++, offset += itemSize) {
+		[self deserializeDataAt:(char*)data + offset
+		      ofObjCType:itemType
+		      atCursor:cursor
+		      context:callback];
+	    }
 	    break;
 	}
 	case _C_STRUCT_B: {
@@ -637,17 +639,18 @@
 	}
         case _C_ARY_B: {
             int i, offset, itemSize, count = Atoi(type + 1);
-            const unsigned char* itemType = type;
+            const char *itemType = type;
+	    
+            while (isdigit(*++itemType))
+		;
+	    itemSize = objc_sizeof_type(itemType);
 
-            while(isdigit(*++itemType));
-		itemSize = objc_sizeof_type(itemType);
-
-		for(i = offset = 0; i < count; i++, offset += itemSize)
-		    [self serializeDataAt:(char*)data + offset
-			    ofObjCType:itemType
-			    context:callback];
-
-		break;
+	    for (i = offset = 0; i < count; i++, offset += itemSize) {
+		[self serializeDataAt:(char*)data + offset
+		      ofObjCType:itemType
+		      context:callback];
+	    }
+	    break;
         }
         case _C_STRUCT_B: {
             int offset = 0;
