@@ -323,7 +323,7 @@ static inline const char *index(const char *cstr, char c) {
     {
         register const unsigned char *cfmt;
         hasThousandSep = NO;
-        if ((cfmt = [format cString])) {
+        if ((cfmt = (const unsigned char *)[format cString]) != NULL) {
             for ( ; *cfmt != '\0' && !hasThousandSep; cfmt++) {
                 if (*cfmt == self->thousandSeparator)
                     hasThousandSep = YES;
