@@ -57,7 +57,7 @@ extern NSRecursiveLock* libFoundationLock;
     SEL selector;
 }
 + holderForTarget:(id)target argument:(id)argument selector:(SEL)action;
-- (BOOL)isEqual:anotherHolder;
+- (BOOL)isEqual:(_NSObjectDelayedExecutionHolder *)anotherHolder;
 - (void)execute;
 @end
 
@@ -79,7 +79,7 @@ extern NSRecursiveLock* libFoundationLock;
   return [(NSObject *)self->target hash];
 }
 
-- (BOOL)isEqual:(_NSObjectDelayedExecutionHolder*)anotherHolder
+- (BOOL)isEqual:(_NSObjectDelayedExecutionHolder *)anotherHolder
 {
     return [(NSObject *)self->target isEqual:anotherHolder->target]
 	    && [(NSObject *)self->argument isEqual:anotherHolder->argument]
@@ -100,6 +100,13 @@ Class lfNSZoneClass = Nil; /* cache NSZone class */
 static BOOL 
 objc_runtime_exception(id object, int code, const char* fmt, va_list ap)
 {
+#if 1 && 0
+#  warning TEST LOG, REMOVE ME!
+    printf("ObjC: object=0x%08X code=%i\n", (unsigned int)object, code);
+    if (fmt != NULL)
+	vprintf(fmt, ap);
+#endif
+    
     [[[ObjcRuntimeException alloc] initWithFormat:
 		    @"Objective-C runtime error: %@",
 		    Avsprintf([NSString stringWithCString:fmt], ap)] raise];
@@ -609,7 +616,7 @@ static NSMutableDictionary* delayedExecutions = nil;
 - (id)performSelector:(SEL)aSelector withObject:(id)anObject
 {
     struct objc_method  *mth;
-    const unsigned char *argType;
+    const char *argType;
 
     if (aSelector == NULL) {
 	[[[ObjcRuntimeException alloc]
